// Reference - https://github.com/wswebcreation/start-ios-simulator/blob/master/lib/index.js
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { execFileSync } from 'child_process';
import chalk from 'chalk';
import inquirer from 'inquirer';
const MESSAGE_TYPES = {
    ERROR: 'error',
    NOTIFY: 'notify',
    STEP: 'step',
    WARNING: 'warning',
};
export default function startiOSSimulator() {
    return __awaiter(this, void 0, void 0, function* () {
        const simulators = getAllSimulators();
        const questions = [
            {
                type: 'list',
                name: 'simulator',
                message: 'On which simulator do you want to run your test?',
                choices: simulators,
            },
        ];
        logMessage(MESSAGE_TYPES.NOTIFY, 'iOS iPhone|iPad CLI Helper');
        if (simulators.length > 0) {
            const answer = yield inquirer.prompt(questions);
            const chosenSimulator = simulators.find((simulator) => simulator.name === answer.simulator);
            closeBootedSimulator(chosenSimulator);
            bootSimulator(chosenSimulator);
            startSimulator(chosenSimulator);
        }
    });
}
function getAllSimulators() {
    const simulators = [];
    const devices = JSON.parse(execFileSync('xcrun', ['simctl', 'list', '--json', 'devices'], { encoding: 'utf8' })).devices;
    Object.keys(devices)
        .filter((version) => version.includes('iOS'))
        .forEach((version) => devices[version].map((simulator) => {
        if (simulator.isAvailable) {
            simulators.push(Object.assign(Object.assign({}, simulator), { name: `${simulator.name} ${version.split('-')[1]}.${version.split('-')[2]}`, version: version.split(' ')[1] }));
        }
    }));
    return simulators;
}
function closeBootedSimulator(chosenSimulator) {
    if (chosenSimulator.state === 'Booted') {
        stepMessage(MESSAGE_TYPES.WARNING, `The ${chosenSimulator.name} is already opened. It will be closed.`);
        execFileSync('xcrun', ['simctl', 'shutdown', chosenSimulator.udid], { encoding: 'utf8' });
        stepMessage(MESSAGE_TYPES.STEP, `${chosenSimulator.name} has been shut down.`);
    }
}
function bootSimulator(chosenSimulator) {
    execFileSync('xcrun', ['simctl', 'boot', chosenSimulator.udid], { encoding: 'utf8' });
    stepMessage(MESSAGE_TYPES.STEP, `${chosenSimulator.name} wil be booted.`);
}
function startSimulator(chosenSimulator) {
    stepMessage(MESSAGE_TYPES.STEP, `${chosenSimulator.name} wil be opened.`);
    execFileSync('open', ['-a', 'Simulator.app'], { encoding: 'utf8' });
}
/**
 * Print the message
 *
 * @param {string} type
 * @param {string} message
 */
function logMessage(type, message) {
    const messageType = type === MESSAGE_TYPES.NOTIFY ? chalk.cyan : chalk.red;
    console.log(messageType(`
====================================================================================================
  
  ${message}
  
====================================================================================================
`));
}
/**
 * Print the step
 *
 * @param {string} type
 * @param {string} stepMessage
 */
function stepMessage(type, stepMessage) {
    const messageType = type === MESSAGE_TYPES.STEP ? chalk.green : chalk.yellow;
    console.log(messageType(`\n${stepMessage}`));
}
//# sourceMappingURL=ios.js.map